@@ -133,6 +133,8 @@ class FileSystemManager(object):
                     'compatible': ['ntfs']}}
 
     default_param = {'defaultopt': defaultOpt,
+                     'gpt': '8300',
+                     'msdos': '83',
                      'ssd': []}
 
     @classmethod
@@ -165,7 +167,7 @@ class FileSystemManager(object):
 
     @classmethod
     def checkFSForTypeMount(cls, fs, roottype, mp):
-        if mp == '/boot/efi':
+        if mp.startswith('/boot/efi'):
             if fs not in ('uefi', 'vfat'):
                 return False
             else:
