@@ -311,11 +311,9 @@ class VariableClAutopartitionDevice(AutopartitionHelper, Variable):
                 sb = self.Get('cl_autopartition_scheme_builder')
                 if sb and sb.devices:
                     sb.process(df)
-            except (partition.DeviceSchemeError,
+            except (partition.SchemeError,
                     partition.VirtualDiskError) as e:
                 raise VariableError(str(e))
-            except partition.SchemeError:
-                pass
             if self.GetBool('cl_autopartition_uefi_set'):
                 if not self.Get('cl_autopartition_efi'):
                     raise VariableError(
@@ -352,6 +350,10 @@ class VariableClAutopartitionSchemeBuilder(ReadonlyVariable):
         if SchemeOpt.Calculate in scheme:
             sb.calculate = True
 
+        deviceSizeAll = int(self.Get('cl_autopartition_device_size_all'))
+        if not sb.update and not sb.calculate and deviceSizeAll == sb.root_size:
+            sb.rootall = True
+
         sb.minimal_calculate_size = \
             int(self.Get('cl_autopartition_calculate_size'))
 
@@ -410,7 +412,6 @@ class VariableClAutopartitionSet(Variable):
     """
     type = "bool"
     element = "radio"
-    opt = ["--autopartition", "-p"]
 
     def init(self):
         self.label = _("Allocate drive space")
@@ -419,9 +420,13 @@ class VariableClAutopartitionSet(Variable):
     def choice(self):
         name = "Calculate Linux"
         return [("on", _("Erase disk and install %s") % name),
-                ("off", _("Use the current partitions"))]
+                ("off", _("Use current partitions"))]
 
     def get(self):
+        if self.is_console_set("os_location_data"):
+            return "off"
+        elif self.is_console_set("cl_autopartition_device"):
+            return "on"
         if self.Get('os_root_type_ext') in (RootType.Value.LiveCD,
                                             RootType.Value.LiveFlash,
                                             RootType.Value.IsoScanFlash,
@@ -504,6 +509,18 @@ class VariableClAutopartitionRootSizeMin(Variable):
     value = str(Sizes.G * 7)
 
 
+class VariableClAutopartitionDeviceSizeAll(ReadonlyVariable):
+    """
+    Общий объем дискового пространства
+    """
+    def get(self):
+        deviceSize = sum(
+            int(x) for x in self.Get('cl_autopartition_device_size'))
+        scheme = self.Get('cl_autopartition_scheme')
+        if SchemeOpt.Swap in scheme:
+            return deviceSize - int(self.Get('cl_autopartition_swap_size'))
+        return deviceSize
+
 class VariableClAutopartitionRootSize(SizeHelper, AutopartitionHelper,
                                       Variable):
     """
@@ -518,12 +535,15 @@ class VariableClAutopartitionRootSize(SizeHelper, AutopartitionHelper,
         self.label = _("Root partition size") + " (MB)"
         self.help = _("set the root partition size for autopartition")
 
+    def use_rootall(self):
+        scheme = self.Get('cl_autopartition_scheme')
+        return SchemeOpt.Update not in scheme and SchemeOpt.Calculate not in scheme
+
     def get(self):
         size = int(self.Get('cl_autopartition_root_size_default'))
-        deviceSize = sum(
-            int(x) for x in self.Get('cl_autopartition_device_size'))
+        deviceSize = int(self.Get('cl_autopartition_device_size_all'))
         minRootSize = int(self.Get('cl_autopartition_root_size_min'))
-        if size >= deviceSize:
+        if size >= deviceSize or self.use_rootall():
             size = max(deviceSize, minRootSize)
         return str(size)
 
