@@ -68,7 +68,8 @@ class Wsdl(WsdlBase):
                                 image="welcome",
                                 normal=('os_install_locale_lang',
                                         'os_install_clock_timezone'),
-                                expert=('os_install_locale_keyboard_layout',)),
+                                expert=('os_install_locale_keyboard_layout',
+                                        'os_install_clock_type',)),
             lambda group: group(_("Distribution"),
                                 normal=('cl_image_filename',),
                                 hide=('cl_image_linux_shortname',
@@ -357,6 +358,7 @@ class Wsdl(WsdlBase):
                                             'os_install_clock_timezone'),
                                     expert=(
                                         'os_install_locale_keyboard_layout',
+                                        'os_install_clock_type',
                                         'cl_templates_locate',
                                         'cl_dispatch_conf',
                                         'cl_verbose_set'),
